@@ -1,7 +1,7 @@
 /**
  * Python plugin for Orthanc
- * Copyright (C) 2020-2022 Osimis S.A., Belgium
- * Copyright (C) 2021-2022 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
+ * Copyright (C) 2020-2023 Osimis S.A., Belgium
+ * Copyright (C) 2021-2023 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -40,5 +40,12 @@ public:
                          PyObject*& singletonCallback,
                          const std::string& details);
 
+  // The GIL must be locked
+  static PyObject *Apply2(ICallbackRegistration& registration,
+                          PyObject* args,
+                          PyObject*& singletonCallback1,
+                          PyObject*& singletonCallback2,
+                          const std::string& details);
+
   static void Unregister(PyObject*& singletonCallback);
 };
