@@ -1,6 +1,7 @@
 /**
  * Python plugin for Orthanc
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2020-2023 Osimis S.A., Belgium
+ * Copyright (C) 2021-2023 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -19,15 +20,37 @@
 
 #include "PythonString.h"
 
-#include <OrthancPluginCppWrapper.h>
+#include "../Resources/Orthanc/Plugins/OrthancPluginCppWrapper.h"
 
-PythonString::PythonString(PythonLock& lock,
-                           const std::string& utf8) :
-  string_(lock, PyUnicode_FromString(utf8.c_str()))
+
+void PythonString::SanityCheck()
 {
-  if (!string_.IsValid())
+  if (!string_->IsValid())
   {
-    OrthancPlugins::LogError("Cannot create a Python string");
+    OrthancPlugins::LogError("Cannot create a Python string, check that the string is properly encoded using UTF-8");
     ORTHANC_PLUGINS_THROW_EXCEPTION(InternalError);
   }
 }
+
+
+PythonString::PythonString(PythonLock& lock,
+                           const std::string& utf8)
+{
+  string_.reset(new PythonObject(lock, PyUnicode_FromString(utf8.c_str())));
+  SanityCheck();
+}
+
+
+PythonString::PythonString(PythonLock& lock,
+                           const char* utf8)
+{
+  if (utf8 == NULL)
+  {
+    ORTHANC_PLUGINS_THROW_EXCEPTION(NullPointer);
+  }
+  else
+  {
+    string_.reset(new PythonObject(lock, PyUnicode_FromString(utf8)));
+    SanityCheck();
+  }
+}
